.. _install:

Installation
============

This part of the documentation covers the installation of Flask-OAuthlib.


Pip
---

Installing Flask-OAuthlib is simple with `pip <http://www.pip-installer.org/>`_::

    $ pip install Flask-OAuthlib


Cheeseshop Mirror
-----------------

If the Cheeseshop is down, you can also install Flask-OAuthlib from one of the
mirrors. `Crate.io <http://crate.io>`_ is one of them::

    $ pip install -i http://simple.crate.io/ Flask-OAuthlib


Get the Code
------------

Flask-OAuthlib is actively developed on GitHub, where the code is
`always available <https://github.com/lepture/flask-oauthlib>`_.

You can either clone the public repository::

    git clone git://github.com/lepture/flask-oauthlib.git

Download the `tarball <https://github.com/lepture/flask-oauthlib/tarball/master>`_::

    $ curl -OL https://github.com/lepture/flask-oauthlib/tarball/master

Or, download the `zipball <https://github.com/lepture/flask-oauthlib/zipball/master>`_::

    $ curl -OL https://github.com/lepture/flask-oauthlib/zipball/master


Once you have a copy of the source, you can embed it in your Python package,
or install it into your site-packages easily::

    $ python setup.py install
